package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.CardReplacementRecord;

/**
 * 补卡记录Mapper接口
 * 
 * @author ruoyi
 * @date 2023-02-08
 */
public interface CardReplacementRecordMapper 
{
    /**
     * 查询补卡记录
     * 
     * @param id 补卡记录主键
     * @return 补卡记录
     */
    public CardReplacementRecord selectCardReplacementRecordById(Long id);

    /**
     * 查询补卡记录列表
     * 
     * @param cardReplacementRecord 补卡记录
     * @return 补卡记录集合
     */
    public List<CardReplacementRecord> selectCardReplacementRecordList(CardReplacementRecord cardReplacementRecord);

    /**
     * 新增补卡记录
     * 
     * @param cardReplacementRecord 补卡记录
     * @return 结果
     */
    public int insertCardReplacementRecord(CardReplacementRecord cardReplacementRecord);

    /**
     * 修改补卡记录
     * 
     * @param cardReplacementRecord 补卡记录
     * @return 结果
     */
    public int updateCardReplacementRecord(CardReplacementRecord cardReplacementRecord);

    /**
     * 删除补卡记录
     * 
     * @param id 补卡记录主键
     * @return 结果
     */
    public int deleteCardReplacementRecordById(Long id);

    /**
     * 批量删除补卡记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCardReplacementRecordByIds(Long[] ids);

    List<CardReplacementRecord> selectCardReplacementRecordListWeek(CardReplacementRecord cardReplacementRecord);
}
